import * as ec2 from "aws-cdk-lib/aws-ec2";
import * as events from "aws-cdk-lib/aws-events";
import * as rds from "aws-cdk-lib/aws-rds";
import { Construct } from "constructs";
export declare enum DbEngine {
    MYSQL = "mysql"
}
export interface RdsDumpProps {
    /**
     * Select DB engine type. Currently only mysql can be selected.
     */
    readonly dbEngine: DbEngine;
    /**
     * RDS Cluster to dump.
     */
    readonly rdsCluster: rds.DatabaseCluster;
    /**
     * Schedule to dump. See aws-cdk-lib/aws-events.Schedule.
     * ex.
     * import * as events from 'aws-cdk-lib/aws-events'
     * // It is executed daily at 00:00 UTC.
     * events.Schedule.cron({ minute: "0", hour: "0" })
     */
    readonly schedule: events.Schedule;
    /**
     * Database name to dump.
     */
    readonly databaseName: string;
    /**
     * Suffix to add to the resource ID.
     * @default - no suffix
     */
    readonly idSuffix?: string;
    /**
     * Security group to allow access to the lambda function.
     *
     * @default - use auto generated security group
     */
    readonly lambdaNsg?: ec2.ISecurityGroup[];
    /**
     * Environment variables to set in the lambda function.
     * ex. { "ENV_VAR": "value" }
     *
     * @default - no environment variables
     */
    readonly lambdaEnv?: {
        [key: string]: string;
    };
    /**
     * Database username.
     *
     * We recommend using the secret stored in the Secrets Manager as the connection information to the DB,
     * but it is also possible to specify the user name and password directly.
     * unsecureUserName is a parameter to pass the user name when the `unsecurePassword` is used.
     *
     * @default - do not use unsecureUserName
     */
    readonly unsecureUserName?: string;
    /**
     * Database Password.
     *
     * We recommend using the secret stored in the Secrets Manager as the connection information to the DB,
     * but it is also possible to specify the user name and password directly.
     * unsecurePassword is a parameter to pass the password when the `unsecureUsername` is used.
     *
     * @default - do not use unsecurePassword
     */
    readonly unsecurePassword?: string;
    /**
     * Secret id for database connection information stored in the Secrets Manager.
     *
     * We recommend using the secret stored in the Secrets Manager as the connection information to the DB,
     * but it is also possible to specify the user name and password directly.
     * If secretId is set, the corresponding secret on SecretsManager is retrieved to access the DB.
     *
     * @default - use database cluster's secret
     */
    readonly secretId?: string;
    /**
     * Whether to create an Interface Endpoint for the Secrets Manager.
     *
     * It is recommended to use a secret stored in the Secrets Manager,
     * but in that case, the lambda doing the dump needs a route to access the Secrets Manager.
     * If createSecretsManagerVPCEndpoint is true, an Interface Endpoint is created to allow access to the Secrets Manager.
     *
     * @default false
     */
    readonly createSecretsManagerVPCEndpoint?: boolean;
    /**
     * Whether to create an S3 Gateway Endpoint for the VPC where the RDS is located.
     *
     * @default false
     */
    readonly createS3GatewayEndpoint?: boolean;
    /**
     * List of IDs of security groups to attach to the Interface Endpoint for Secrets Manager.
     * Only used if createSecretsManagerVPCEndpoint is true.
     *
     * @default - use auto generated security group
     */
    readonly secretsManagerVPCEndpointNsgId?: string;
    /**
     * The amount of memory in MB allocated to the Lambda function.
     *
     * @default 1024
     */
    readonly memorySize?: number;
}
export declare class RdsDump extends Construct {
    constructor(scope: Construct, id: string, { dbEngine, rdsCluster, databaseName, idSuffix, schedule, lambdaNsg, lambdaEnv, unsecureUserName, unsecurePassword, secretId, createSecretsManagerVPCEndpoint, createS3GatewayEndpoint, secretsManagerVPCEndpointNsgId, memorySize, }: RdsDumpProps);
}
